@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Access to the AcousticBrainz API
 
-our $VERSION = '0.0400';
+our $VERSION = '0.0401';
 
 use Moo;
 use strictures 2;
@@ -14,6 +14,7 @@ use Mojo::UserAgent;
 use Mojo::JSON::MaybeXS;
 use Mojo::JSON qw( decode_json );
 use Mojo::URL;
+use Try::Tiny;
 
 
 has base => (
@@ -59,10 +60,10 @@ sub _handle_response {
 
     if ( $res->is_success ) {
         my $body = $res->body;
-        if ( $body =~ /{/ ) {
+        try {
             $data = decode_json( $res->body );
         }
-        else {
+        catch {
             croak $body, "\n";
         }
     }
@@ -87,7 +88,7 @@ WebService::AcousticBrainz - Access to the AcousticBrainz API
 
 =head1 VERSION
 
-version 0.0400
+version 0.0401
 
 =head1 SYNOPSIS
 
